#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_CHOW_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_CHOW_HPP_INCLUDED

#include <nt2/gallery/include/functions/scalar/chow.hpp>

#endif
